@@ -1,6 +1,8 @@
 from pm4py.util.constants import CASE_CONCEPT_NAME
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY
-from pm4py.util.constants import PARAMETER_CONSTANT_CASEID_KEY, PARAMETER_CONSTANT_ACTIVITY_KEY, GROUPED_DATAFRAME
+from pm4py.util.constants import GROUPED_DATAFRAME
+from pm4py.statistics.parameters import Parameters
+from pm4py.util import exec_utils
 
 
 def get_end_activities(df, parameters=None):
@@ -13,8 +15,8 @@ def get_end_activities(df, parameters=None):
         Pandas dataframe
     parameters
         Parameters of the algorithm, including:
-            case_id_glue -> Case ID column in the dataframe
-            activity_key -> Column that represents the activity
+            Parameters.CASE_ID_KEY -> Case ID column in the dataframe
+            Parameters.ACTIVITY_KEY -> Column that represents the activity
 
     Returns
     -----------
@@ -24,10 +26,8 @@ def get_end_activities(df, parameters=None):
     if parameters is None:
         parameters = {}
 
-    case_id_glue = parameters[
-        PARAMETER_CONSTANT_CASEID_KEY] if PARAMETER_CONSTANT_CASEID_KEY in parameters else CASE_CONCEPT_NAME
-    activity_key = parameters[
-        PARAMETER_CONSTANT_ACTIVITY_KEY] if PARAMETER_CONSTANT_ACTIVITY_KEY in parameters else DEFAULT_NAME_KEY
+    case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, DEFAULT_NAME_KEY)
     grouped_df = parameters[GROUPED_DATAFRAME] if GROUPED_DATAFRAME in parameters else None
 
     if grouped_df is None:
