@@ -1,3 +1,5 @@
+import deprecation
+
 from pm4py.visualization.decisiontree.versions import classic
 from pm4py.visualization.common import gview
 from pm4py.visualization.common import save as gsave
@@ -7,10 +9,11 @@ CLASSIC = "classic"
 
 VERSIONS = {CLASSIC: classic.apply}
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use visualizer module instead.')
 def apply(clf, feature_names, classes, parameters=None, variant="classic"):
     """
-    Factory method to apply the visualization of the decision tree
+    Method to apply the visualization of the decision tree
 
     Parameters
     ------------
@@ -33,7 +36,8 @@ def apply(clf, feature_names, classes, parameters=None, variant="classic"):
     """
     return VERSIONS[variant](clf, feature_names, classes, parameters=parameters)
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use visualizer module instead.')
 def save(gviz, output_file_path):
     """
     Save the diagram
@@ -47,7 +51,8 @@ def save(gviz, output_file_path):
     """
     gsave.save(gviz, output_file_path)
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use visualizer module instead.')
 def view(gviz):
     """
     View the diagram
